BlazeWeb
########

.. image:: https://ci.appveyor.com/api/projects/status/4b6d40cr79s5p41f?svg=true
    :target: https://ci.appveyor.com/project/level12/blazeweb

.. image:: https://circleci.com/gh/blazelibs/blazeweb.svg?style=shield
    :target: https://circleci.com/gh/blazelibs/blazeweb

.. image:: https://codecov.io/gh/blazelibs/blazeweb/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/blazelibs/blazeweb

Intro
-----

BlazeWeb (formerly pysmvt) is a WSGI web framework library designed to be
relatively "light weight", but with a powerful plug-in and override architecture
that facilitates modularized development.

Questions & Comments
---------------------

Please visit: http://groups.google.com/group/blazelibs

Current Status
---------------

The code stays pretty stable, but some of the API will probably
change in the future.

The `BlazeWeb tip <http://github.com/blazelibs/blazeweb/archive/master.zip#egg=BlazeWeb-dev>`_
is installable via `easy_install` with ``easy_install BlazeWeb==dev``
